@@ -6,13 +6,15 @@ use warnings;
 use Text::Trac::Context;
 use Text::Trac::BlockNode;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 my %Defaults = (
 	html              => '',
 	permalink         => '',
 	min_heading_level => 1,
 	class             => 1,
+	id                => 1,
+	span              => 1,
 );
 
 sub new {
@@ -150,9 +152,9 @@ Return converted html string.
 
 =item  L<Text::Hatena>
 
-=item  Trac L<http://www.edgewall.com/trac/>
+=item  L<Trac Guide|https://trac.edgewall.org/wiki/TracGuide>
 
-=item  Trac WikiFormatting L<http://projects.edgewall.com/trac/wiki/WikiFormatting>
+=item  L<Trac WikiFormatting|https://trac.edgewall.org/wiki/WikiFormatting>
 
 =back
 
